import {Component, OnInit} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {Commons} from '../../commons';
import {AppService} from '../../app.service';
import {ResetpwdService} from './resetpwd.service';
import {Result} from '../../interface/Result';
import {MessageService} from '../../message/message.service';
import {Router} from '@angular/router';

@Component({
  selector: 'app-resetpwd',
  templateUrl: './resetpwd.component.html',
  styleUrls: ['./resetpwd.component.scss']
})
// 重置密码模块
export class ResetpwdComponent extends Commons implements OnInit {

  // 重置密码表单
  resetForm = this.fb.group({
    // 管理员名
    managerName: this.fb.control('', [Validators.required]),
    // 邮箱
    email: this.fb.control('', [Validators.required]),
    // 验证码
    verificationCode: this.fb.control('', [Validators.required]),
    // 邮箱类型
    emailType: this.fb.control('', [Validators.required]),
    // 新密码
    password: this.fb.control('', [Validators.required]),
    // 确认新密码
    confirmPassword: this.fb.control('', [this.checkPwd()]),
  });

  /**
   * 邮箱类型
   */
  emailType$ = this.appService.getEmailType();

  // 当前步骤
  step = 1;

  constructor(
    private fb: FormBuilder,
    private appService: AppService,
    private resetpwdService: ResetpwdService,
    private messageService: MessageService,
    private router: Router
  ) {
    super();
  }

  //
  ngOnInit(): void {

  }


  // 检查邮箱
  checkEmail() {
    this.resetpwdService.checkEmail(this.resetForm.value).subscribe(r => {
      if (r.result === Result.OK) {
        // this.messageService.info('邮箱正确');
        // 进入第二步
        this.step = 2;
        // 清空提示
        this.messageService.message = null;
        // 第二步不允许编辑账户和邮箱
        this.disabled();
      } else {
        this.messageService.danger('账号或邮箱错误');
      }
    });
  }

  // 第二步不允许编辑账户和邮箱
  disabled() {
    this.getValue('managerName').disable();
    this.getValue('email').disable();
    this.getValue('emailType').disable();
  }

  enabled() {
    this.getValue('managerName').enable();
    this.getValue('email').enable();
    this.getValue('emailType').enable();
  }

  // 发送验证码
  sendCode() {
    this.resetpwdService.sendCode({
      managerName: this.getValue('managerName').value
    }).subscribe(res => {
      this.disabled();
      if (res.result === Result.OK) {
        this.messageService.info('验证码发送成功，请查收验证码');
      } else {
        this.messageService.danger('验证码发送失败，请重试或联系管理员');
      }
    });
  }

  // 返回第一步
  backFirst() {
    this.step = 1;
    this.enabled();
    this.getValue('verificationCode').reset();
  }

  /**
   * 检查验证码
   */
  checkCode() {
    this.resetpwdService.checkCode({
      managerName: this.getValue('managerName').value
    }).subscribe(res => {
      if (res.result === Result.OK) {
        // 进入第三步
        this.step = 3;
        // 清空提示
        this.messageService.message = null;
      } else {
        this.messageService.danger('验证码不正确，请重新输入');
      }
    });
  }

  /**
   * 重置密码
   */
  resetPwd() {
    this.resetpwdService.resetPwd({
      managerName: this.getValue('managerName').value,
      password: this.getValue('password').value
    }).subscribe(res => {
      if (res.result === Result.OK) {
        this.messageService.info('重制密码成功');
        this.router.navigateByUrl('/login');
      } else {
        this.messageService.danger('重置密码失败');
      }
    });
  }

  form(): FormGroup {
    return this.resetForm;
  }

  /**
   * 检查是否允许进入第二步
   */
  allowCheckEmail() {
    return this.getValue('managerName').invalid || this.getValue('email').invalid || this.getValue('emailType').invalid;
  }

}
